nvector.objects.FrameL — nvector 0.7.5 documentation

# nvector.objects.FrameL

class `FrameL`(position, wander_azimuth=0)

  Local level, Wander azimuth frame

  Parameters
    position: ECEFvector, GeoPoint or Nvector object

      position of the vehicle (B) which also defines the origin of the local frame L. The origin is directly beneath or above the vehicle (B), at Earth’s surface (surface of ellipsoid model).

    wander_azimuth: real scalar

      Angle [rad] between the x-axis of L and the north direction.

  See also

  `FrameE`, `FrameN`, `FrameB`

  Notes

  The Cartesian frame is local and oriented Wander-azimuth-Down. This means that the z-axis is pointing down. Initially, the x-axis points towards north, and the y-axis points towards east, but as the vehicle moves they are not rotating about the z-axis (their angular velocity relative to the Earth has zero component along the z-axis).

  (Note: Any initial horizontal direction of the x- and y-axes is valid for L, but if the initial position is outside the poles, north and east are usually chosen for convenience.)

  The L-frame is equal to the N-frame except for the rotation about the z-axis, which is always zero for this frame (relative to E). Hence, at a given time, the only difference between the frames is an angle between the x-axis of L and the north direction; this angle is called the wander azimuth angle. The L-frame is well suited for general calculations, as it is non-singular.

  `__init__`(self, position, wander_azimuth=0)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `Pvector`(self, pvector) | Returns Pvector relative to the local frame.
  `__init__`(self, position[, wander_azimuth]) | Initialize self.

  Attributes

  `R_EN` | Rotation matrix to go between E and L frame